s!^/FamilyName (MarVoSym.*)!/FamilyName (MarVoSym with TeX support)!
s!^/FullName (MarVoSym.*)!/FullName (MarVoSym with TeX support)!
s!^/Notice (.*)!/Notice (Martin Vogel's Symbols, including this derivative with TeX support, are released under the Open Font License - see http://ctan.org/pkg/marvosym)!
s!^/version (Version!/version (TeX version of August 2011, based on original Version!
